[−][src]Struct drone_config::Config
Config object.
Fields
memory: Memoryheap: Heapbmp: Option<Bmp>Methods
impl Config[src]
pub fn read_from_current_dir() -> Result<Self, Error>[src]
Reads the configuration file from the current working directory and returns a parsed object.
pub fn read_from_cargo_manifest_dir() -> Result<Self, Error>[src]
Reads the configuration file from the CARGO_MANIFEST_DIR environment
variable path and returns a parsed object.
If CARGO_MANIFEST_DIR_OVERRIDE environment variable is set, the
function will parse its value directly.
pub fn read(crate_root: &Path) -> Result<Self, Error>[src]
Reads the configuration file at crate_root and returns a parsed
object.
pub fn parse(string: &str) -> Result<Self, Error>[src]
Parses config from the string.
pub fn bmp(&self) -> Result<&Bmp, Error>[src]
Returns bmp section or an error if not defined.